@@ -1,11 +1,12 @@
 import asyncio
 import unittest
-from cool_open_client.cool_automation_client import CoolAutomationClient
+from cool_open_client.cool_automation_client import CoolAutomationClient, InvalidTokenException
 
 
 class CoolAutomationClientTest(unittest.TestCase):
     def setUp(self):
-        self.token = "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJpZCI6IjYxZjhkYmFlYThhMzFjMTk2NmIxZWNlYyIsImlhdCI6MTY0OTc2MDQxNiwiZXhwIjoxNjgxMzE4MDE2fQ.RLwz3qiZgLBRwHYpPQGrYtPC3t34axQBh2C7pP_wdVU"
+        with open("token.txt", "r", encoding='utf-8') as token_file:
+            self.token = token_file.read()
         self.loop = asyncio.get_event_loop()
         self.client = self.loop.run_until_complete(CoolAutomationClient.create(token=self.token))
 
@@ -27,6 +28,20 @@ class CoolAutomationClientTest(unittest.TestCase):
         response = self.loop.run_until_complete(self.client.get_me())
         print(response)
 
+    def test_get_dictionary(self):
+        response = self.loop.run_until_complete(self.client.get_dictionary())
+        print(response)
+
+    def test_get_dictionary_bad_token(self):
+        with open("bad_token.txt", "r", encoding='utf-8') as token_file:
+            token = token_file.read()
+        try:
+            client = self.loop.run_until_complete(CoolAutomationClient.create(token=token))
+        except InvalidTokenException as e:
+            print("Invalid Token Exception")
+        except Exception as e:
+            raise e
+
     def test_set_hvac_mode(self):
         mode = "COOL"
         unit_id = "61f8e55b60bf483d1e5aeef6"
